@@ -5,9 +5,11 @@
 @year: 2017
 @license: GNU GPLv3 <https://gitlab.com/malfatti/SciScripts/raw/master/LICENSE>
 @homepage: https://gitlab.com/Malfatti/SciScripts
+
+Functions for analysis of ABR recordings.
 """
 
-print('[Analysis.ABRs] Importing dependencies...')
+print('[Analysis.ABRs] Loading dependencies...')
 import numpy as np
 import os
 
@@ -20,23 +22,157 @@ from sciscripts.IO import IO
 print('[Analysis.ABRs] Done.')
 
 ## Level 0
-def ABRPerCh(Data, Rate, TTLs, ABRCh, TimeWindow, FilterFreq, FilterOrder=4, FilterCoeff='butter', Filter='bandpass'):
-    Len = abs(int((Rate*TimeWindow[0])-(Rate*TimeWindow[1])))
-    ABRs = np.zeros((Len, len(ABRCh)), dtype=Data.dtype)
-    for C,Ch in enumerate(ABRCh):
-        ABR = Analysis.FilterSignal(Data[:,Ch-1], Rate, FilterFreq, FilterOrder, FilterCoeff, Filter)
-        ABR = Analysis.SliceData(ABR, TTLs,
-                                     -int(TimeWindow[0]*Rate),
-                                     int(TimeWindow[1]*Rate),
-                                     )
-        ABR *= 1000 # to µV
-        ABRs[:,C] = ABR.mean(axis=1)
-        del(ABR)
+def ABRPerCh(Data, Rate, TTLs, TimeWindow, FilterFreq=[600,1500], FilterOrder=4, FilterCoeff='butter', Filter='bandpass'):
+    """
+    Extract ABR signal from each channel of Data.
 
+    Filters according to FilterFreq, FilterOrder, FilterCoeff and Filter; slice
+    around TTLs according to TimeWindow; and average the sliced trials for each
+    channel in Data.
+
+    Parameters
+    ----------
+    Data: array_like
+        The input array, containing two dimensions ([samples, channels]).
+
+    Rate: int
+        Sampling rate of Data.
+
+    TTLs: array_like
+        Array with timestamps of each stimulus onset.
+
+    TimeWindow: array_like
+        Array containing two values, which are the beginning and ending of the
+        window to be analyzed in relation to each timestamp mark.
+
+    FilterFreq: array_like, optional
+        Frequency for filtering each Data channel.
+
+    FilterOrder: int, optional
+        Filter order.
+
+    FilterCoeff: str, optional
+        Filter coefficient type. Can be `'butter'` or `'fir'`.
+
+    Filter: str, optional
+        Type of filtering. Can be `'lowpass'`, `'highpass'` or `'bandpass'`.
+
+    Returns
+    -------
+    ABRs: array_like
+        The ABR signals for each channel in Data.
+    """
+    Len = abs(int((Rate*TimeWindow[0])-(Rate*TimeWindow[1])))
+    ABRs = np.zeros((Len, Data.shape[1]), dtype=Data.dtype)
+    ABRData = Analysis.FilterSignal(Data, Rate, FilterFreq, FilterOrder, FilterCoeff, Filter)
+
+    for Ch in range(ABRData.shape[1]):
+        ABR = Analysis.SliceData(
+            ABRData[:,Ch], TTLs,
+            -int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate),
+        )
+        ABRs[:,Ch] = ABR.mean(axis=1)
+
+    del(ABR)
     return(ABRs)
 
 
 def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
+    """
+    Extract peaks from `ABRs[RefKey][:,BestCh]`, where `BestCh` is the channel
+    with the greatest Root-mean-square. The threshold for peaks are set as
+    `ABRs[RefKey][:,BestCh].std()*Std`, see `sciscripts.Analysis.GetPeaks?` for
+    more details. Then, screen each decreasing intensity for detected peaks
+    that are preceded by a peak in the previous intensity. This way, only peaks
+    that increases latency when decreasing stimulus intensity are kept.
+
+    Parameters
+    ----------
+    ABRs: dict
+        Dictionary containing one array per key, where each array is the ABR
+        signal in response to a particular intensity (dict key). If `ABRs.keys()`
+        are '0','1','2'... the order is mantained, otherwise it'll be sorted
+        reverse (louder intensities analyzed first). Each array should have two
+        dimensions ([samples, channels]), even if channels==1.
+
+    X: array_like, optional
+        Array of timestamps with shape `(ABRs[key].shape[0],)`. Can be provided
+        if the data contains signal from before the stimulus. In this case,
+        peaks detected with index smaller than `np.where((X>=0))[0][0]` will
+        be ignored.
+
+    RefKey: dict key, optional
+        Dict key containing the data that will be used as reference to all the
+        others. If `None` (default), then, if `ABRs.keys()` are '0','1','2'...
+        `RefKey` will be '0'. Otherwise, it will be
+        `sorted(ABRs.keys(), reverse=Rev)[0]`.
+
+    Std: int or float, optional
+        The threshold for detecting peaks is set as the standard deviation for
+        the recording at `ABRs[RefKey]`, multiplied by Std.
+
+    Returns
+    -------
+    AllPeaks: array
+        Two-dimensional array with dimensions [keys, peaks], containing indexes
+        of ABR peaks. The order of keys is as decribed above. The order of
+        peaks detected in the `RefKey` is kept, so that peaks that do not
+        follow the described criteria are replaced by -1.
+
+    Example
+    -------
+        In [10]: ABRs
+        Out[10]:
+        {'80': array([[ 1181, 16285],
+                [37042, 16041],
+                [30807,  4551],
+                ...,
+                [56512,  8017],
+                [46125,  1472],
+                [15484, 60812]]),
+         '70': array([[42270,  4771],
+                [29553, 42571],
+                [ 1899, 41892],
+                ...,
+                [34616, 31499],
+                [ 9830, 60458],
+                [12736, 53194]]),
+         '60': array([[45993, 48502],
+                [23933,  3293],
+                [ 2631, 61917],
+                ...,
+                [33227, 28280],
+                [36086, 51514],
+                [12659, 41927]]),
+         '50': array([[16129, 37416],
+                [65399,  9624],
+                [40702, 13121],
+                ...,
+                [35727,   779],
+                [45576, 17999],
+                [35339, 43360]])}
+
+        In [11]: X
+        Out[11]:
+        array([-5.        , -4.9824854 , -4.96497081, ..., 15.96497081,
+               15.9824854 , 16.        ])
+
+        In [12]: LatencyToPeaks(ABRs, X)
+        array([[136, 178, 205, 239, 274],
+               [139, 180, 207,  -1,  -1],
+               [142, 181,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1],
+               [ -1,  -1,  -1,  -1,  -1]])
+
+    In this example, the first and second peaks were detected until the third
+    strongest intensity, which should be considered the hearing threshold.
+
+    """
     Rev = False if '0' in ABRs else True
     Recs = sorted(ABRs.keys(), reverse=Rev)
 
@@ -47,13 +183,8 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
     if not RefKey: RefKey = Recs[0]
     BestCh = Analysis.GetStrongestCh(ABRs[RefKey])
 
-    if len(X):
-        FixedThreshold = ABRs[RefKey][:,BestCh].std()*Std
-        Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], FixedThreshold=FixedThreshold) for Rec in Recs]
-    else:
-        FixedThreshold = ABRs[RefKey][:,BestCh].std()*Std
-        # Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], FixedThreshold=FixedThreshold) for Rec in Recs]
-        # Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], Std=Std) for Rec in Recs]
+    FixedThreshold = ABRs[RefKey][:,BestCh].std()*Std
+    Peaks = [Analysis.GetPeaks(ABRs[Rec][:,BestCh], FixedThreshold=FixedThreshold) for Rec in Recs]
 
     Peaks = [_['Pos'] for _ in Peaks]
     if len(X): Peaks = [P[X[P] > 0] for P in Peaks]
@@ -120,7 +251,36 @@ def LatencyToPeaks(ABRs, X=[], RefKey=None, Std=1):
 
 
 ## Level 1
-def GetThreshold(ABRs, X, Std=1):
+def GetThreshold(ABRs, X=[], Std=1):
+    """
+    Get hearing threshold from ABR traces as the lowest intensity evoking valid
+    peaks. See `sciscripts.Analysis.ABRs.LatencyToPeaks?` for more details on
+    what is a valid peak.
+
+    Parameters
+    ----------
+    ABRs: dict
+        Dictionary containing one array per key, where each array is the ABR
+        signal in response to a particular intensity (dict key). If `ABRs.keys()`
+        are '0','1','2'... the order is mantained, otherwise it'll be sorted
+        reverse (louder intensities analyzed first). Each array should have two
+        dimensions ([samples, channels]), even if channels==1.
+
+    X: array_like, optional
+        Array of timestamps with shape `(ABRs[key].shape[0],)`. Can be provided
+        if the data contains signal from before the stimulus. In this case,
+        peaks detected with index smaller than `np.where((X>=0))[0][0]` will
+        be ignored.
+
+    Std: int or float, optional
+        The threshold for detecting peaks is set as the standard deviation for
+        the recording at highest intensity, multiplied by Std.
+
+    Returns
+    -------
+
+
+    """
     Peaks = LatencyToPeaks(ABRs, X, Std=Std)
     if Peaks is None or Peaks.mean() == -1:
         return(0)
@@ -150,9 +310,65 @@ def LatencyPerFreq(Files, Freqs, Std=1):
     return(Latencies)
 
 
-def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, FilterOrder=4, Filter='bandpass', Save='', ReturnX=True, Return=True):
-    if ReturnX:
-        X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
+def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOrder=4, Filter='bandpass', File='', ReturnX=True, Return=True):
+    """
+    Extract ABR traces from raw data.
+
+    Process each data channel (see `sciscripts.Analysis.ABRs.ABRPerCh?`)
+    according to the input parameters.
+
+    Parameters
+    ----------
+    Data: array
+        Two-dimensional array ([samples, channels]) containing neural data and
+        a channel containing stimulus timestamp marks.
+
+    Rate: int
+        Sampling rate in which `Data` was acquired.
+
+    ABRCh: list
+        List of channels from `Data` that contains ABR signal, *1-indexed*.
+
+    TTLCh: int
+        Channel from `Data` containing the stimulus timestamps, *1-indexed*.
+
+    TimeWindow: list
+        List containing the start and stop time in relation to each timestamp
+        mark. Values should be in milliseconds.
+
+    FilterFreq: array_like, optional
+        Frequency for filtering each Data channel.
+
+    FilterOrder: int, optional
+        Filter order.
+
+    FilterCoeff: str, optional
+        Filter coefficient type. Can be 'butter' or 'fir'.
+
+    Filter: str, optional
+        Type of filtering. Can be `'lowpass'`, `'highpass'` or `'bandpass'`.
+
+    File: str, optional
+        File for saving the array containing the processed ABR signals. If
+        empty, no file will be saved.
+
+    Return: bool, optional
+        Toggle for disabling the return of the resulting ABR array. Useful for
+        when running several datasets and writing the results to files (see
+        `sciscripts.Analysis.ABRs.Multiple?`).
+
+    Returns
+    -------
+    ABRs: array
+        Two-dimensional array ([samples, channels]) containing the processed
+        ABR signals for each channel in `Data`.
+
+    X: array
+        Array with time values based on `TimeWindow` matching `ABRs.shape[0]`.
+
+    """
+
+    X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
 
     if type(TTLCh) == int:
         TTLs = Analysis.QuantifyTTLsPerRec(True, Data[:,TTLCh-1])
@@ -160,23 +376,19 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, FilterOrder=4, Filt
         TTLs = TTLCh
 
     if len(TTLs) and TTLs[0] != 'Broken':
-        ABRs = ABRPerCh(Data, Rate, TTLs, ABRCh, TimeWindow, FilterFreq, FilterOrder, FilterCoeff='butter', Filter=Filter)
+        ABRs = ABRPerCh(Data[:,[_-1 for _ in ABRCh]], Rate, TTLs, TimeWindow, FilterFreq, FilterOrder, FilterCoeff='butter', Filter=Filter)
     else:
         print('No TTLs in this recording.')
         return(None)
 
-    if Save:
-        if ReturnX:
-            IO.Bin.Write(X, '/'.join(Save.split('/')[:-2])+'/X.dat')
-
-        IO.Bin.Write(ABRs, Save)
+    if File:
+        IO.Bin.Write(X, '/'.join(File.split('/')[:-2])+'/X.dat')
+        IO.Bin.Write(ABRs, File)
 
     if Return:
-        if ReturnX: return(ABRs, X)
-        else: return(ABRs)
+        return(ABRs, X)
     else:
-        if ReturnX: del(ABRs, X)
-        else: del(ABRs)
+        del(ABRs, X)
         return(None)
 
 
@@ -201,8 +413,8 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, Recs='all', Inten
 
         ABRs[Rec_R] = Single(
             Data[Rec], Rate, ABRCh_R, TTLCh_R, TimeWindow, FilterFreq,
-            Save=Save_R, ReturnX=False, Return=Return
-        )
+            File=Save_R, Return=Return
+        )[0]
 
     X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
 
@@ -341,7 +553,7 @@ def WriteRecAndTTLCh(Folders):
     return(None)
 
 
-NoTTLsFile = os.environ['AnalysisPath']+'/Experiments/NoTTLRecs.dict'
+NoTTLsFile = os.environ['ANALYSISPATH']+'/Experiments/NoTTLRecs.dict'
 
 def _PrintOptions():
     print('')
