@@ -301,11 +301,9 @@ def GetPhase(Signal):
             Data[:,C] = GetPhase(Signal[:,C])
 
     else:
-        # Mean = Signal.mean(axis=0)
         # Orders faster when signal size is a power of two, so padding and truncating
         Data = ssig.hilbert(Signal, fftpack.next_fast_len(len(Signal)))[:len(Signal)]
         Data = np.angle(Data)
-        # Data += Mean
 
     return(Data)
 
@@ -344,13 +342,6 @@ def GetTTLInfo(Events, EventRec, TTLCh):
 
 def GetTTLThreshold(TTLCh, StdNo=3):
     if not StdNo: StdNo = 3
-
-    # if np.mean(TTLCh) > 1000:
-    #     print('Sinusoidal stimulation')
-    #     Threshold = (max(TTLCh) - min(TTLCh)) / 2
-    #     return(Threshold)
-    # else:
-    #     print('square pulses stimulation')
     Threshold = np.mean(TTLCh) + StdNo*(np.std(TTLCh))
     return(Threshold)
 
@@ -429,8 +420,10 @@ def Normalize(Data):
 
 
 def Pairwise(iterable):
-    """ from https://docs.python.org/3.6/library/itertools.html#itertools-recipes
-    s -> (s0,s1), (s1,s2), (s2, s3), ..."""
+    """
+    Taken from https://docs.python.org/3.6/library/itertools.html#itertools-recipes
+    s -> (s0,s1), (s1,s2), (s2, s3), ...
+    """
 
     a, b = tee(iterable)
     next(b, None)
@@ -803,8 +796,6 @@ def GetPLVs(SignalRef, SignalResult, Rate, Freqs, FreqBand):
 
 
 def GetStrongestCh(Data):
-    # BestCh = [np.mean(Data[:,Ch]**2)**0.5 for Ch in range(Data.shape[1])]
-    # BestCh = BestCh.index(max(BestCh))
     BestCh = RMS(Data).argmax()
     return(BestCh)
 
