@@ -7,11 +7,13 @@
 @homepage: https://gitlab.com/Malfatti/SciScripts
 """
 
+print('[Analysis.GPIAS] Loading dependencies...')
 import numpy as np
 from scipy import signal
 
 from sciscripts.Analysis import Analysis as sAnalysis
-from sciscripts.IO import IO#, Asdf#, Hdf5
+from sciscripts.IO import IO
+print('[Analysis.GPIAS] Done.')
 
 
 ## Level 0
@@ -84,19 +86,15 @@ def GetExpsIndexesDict(Exps, ExpNames=None):
 
         for File in sorted(Exp):
             GPIASRec = IO.Bin.Read(File)[0]
-            # if 'XValues' in GPIASRec:
-            #     GPIASRec['X'] = GPIASRec.pop('XValues')
-            #     Asdf.Write(GPIASRec, File)
+            # Fix for old recordings
+            if 'XValues' in GPIASRec:
+                GPIASRec['X'] = GPIASRec.pop('XValues')
 
             GPIASRec, X = GPIASRec['GPIAS'], GPIASRec['X']
             Animal = File.split('/')[-1].split('-')[1]
             if Animal not in Indexes_IFAE[E]:
                 Indexes_IFAE[E][Animal], Traces_IFAE[E][Animal] = {}, {}
 
-            # Indexes_IFAE[E][Animal] = {**Indexes_IFAE[E][Animal],
-            #                                  **{K: np.abs(V['GPIASIndex'])
-            #                                     for K, V in GPIASRec['Index'].items()}}
-
             Indexes_IFAE[E][Animal] = {**Indexes_IFAE[E][Animal],
                                              **{K: sAnalysis.GetNegEquiv(V['GPIASIndex'])
                                                 for K, V in GPIASRec['Index'].items()}}
@@ -108,7 +106,7 @@ def GetExpsIndexesDict(Exps, ExpNames=None):
     return(Indexes_IFAE, Traces_IFAE, X)
 
 
-def GetExpsIndexesDictBest(Exps, ExpNames=None):
+def GetExpsIndexesDict_InDev(Exps, ExpNames=None):
     """
     Get index per freq per animal per exp.
     Necessary for retest overriding (the best tested is always the correct one).
@@ -119,19 +117,15 @@ def GetExpsIndexesDictBest(Exps, ExpNames=None):
 
         for File in sorted(Exp):
             GPIASRec = IO.Bin.Read(File)[0]
-            # if 'XValues' in GPIASRec:
-            #     GPIASRec['X'] = GPIASRec.pop('XValues')
-            #     Asdf.Write(GPIASRec, File)
+            # Fix for old recordings
+            if 'XValues' in GPIASRec:
+                GPIASRec['X'] = GPIASRec.pop('XValues')
 
             GPIASRec, X = GPIASRec['GPIAS'], GPIASRec['X']
             Animal = File.split('/')[-1].split('-')[1]
             if Animal not in Indexes_IFAE[E]:
                 Indexes_IFAE[E][Animal], Traces_IFAE[E][Animal] = {}, {}
 
-            # Indexes_IFAE[E][Animal] = {**Indexes_IFAE[E][Animal],
-            #                                  **{K: np.abs(V['GPIASIndex'])
-            #                                     for K, V in GPIASRec['Index'].items()}}
-
             Dict = {K: sAnalysis.GetNegEquiv(V['GPIASIndex']) for K, V in GPIASRec['Index'].items()}
             for K in Dict:
                 if K in Indexes_IFAE[E][Animal]:
@@ -189,26 +183,6 @@ def GetMAF(Indexes_IFAE, Animals, ExpOrder):
         ]
 
 
-
-        ## Indexes_IFAE as dict
-        # FreqsB = sorted(Indexes_IFAE[ExpOrder[0]][Animal].keys(),
-        #                 key=lambda x: [int(y) for y in x.split('-')])
-        # FreqsA = sorted(Indexes_IFAE[ExpOrder[1]][Animal].keys(),
-        #                 key=lambda x: [int(y) for y in x.split('-')])
-
-        # Freqs = [F for F in set(FreqsB).intersection(FreqsA)]
-        #           # if abs(Indexes_IFAE[ExpOrder[1]][Animal][F]) - abs(Indexes_IFAE[ExpOrder[0]][Animal][F]) < -10]
-
-        # ExpFIDiff = [abs(Indexes_IFAE[ExpOrder[1]][Animal][Freq]) -
-        #           abs(Indexes_IFAE[ExpOrder[0]][Animal][Freq]) for Freq in set(FreqsB).intersection(FreqsA)]
-
-        ## Debug
-        # print(Animal)
-        # print('Before', Indexes_IFAE[ExpOrder[0]][Animal])
-        # print('After', Indexes_IFAE[ExpOrder[1]][Animal])
-        # print(ExpFIDiff)
-        # print('')
-
         if not ExpFIDiff: MAF.append(None)
         else: MAF.append(Freqs[ExpFIDiff.index(min(ExpFIDiff))])
 
@@ -227,49 +201,9 @@ def GetMAFIndexes(Indexes_IFAE, MAF, Animals, ExpOrder):
         ).ravel() for E, Exp in enumerate(ExpOrder)
     ]
 
-
-    # Indexes = [[Indexes_IFAE[Exp][Animal][MAF[A]]
-    #             for A, Animal in enumerate(Animals) if MAF[A]]
-    #            for E, Exp in enumerate(ExpOrder)]
-
-    # Override to account for inverted responses
-    # Indexes = [[sAnalysis.GetNegEquiv(_) for _ in Exp] for Exp in Indexes]
-    # Indexes = [[_ if _ > 0 else -_ for _ in Exp] for Exp in Indexes]
-    # Indexes = [[_ if _ < 100 else _-100 for _ in Exp] for Exp in Indexes]
-    # Indexes = [[_ if _ < 100 else 100 for _ in Exp] for Exp in Indexes]
-
     return(Indexes)
 
 
-def IndexCalcOld(Data, Keys, PulseSampleStart, SliceSize):
-    Index = {}
-    for Key in Keys:
-        BGStart = 0; BGEnd = SliceSize
-        PulseStart = PulseSampleStart; PulseEnd = PulseSampleStart + SliceSize
-
-        if type(Data[Key[0]]) == list:
-            if not Data[Key[0]]:
-                print('Key', Key[0], 'is empty. Skipping...')
-                continue
-
-        ResRMSBG = (np.mean(Data[Key[0]][BGStart:BGEnd]**2))**0.5
-        ResRMSPulse = (np.mean(Data[Key[0]][PulseStart:PulseEnd]**2))**0.5
-#            ResRMS = ResRMSPulse
-        if ResRMSPulse < ResRMSBG: ResRMS = ResRMSPulse
-        else: ResRMS = ResRMSPulse - ResRMSBG
-
-        RefRMSBG = (np.mean(Data[Key[1]][BGStart:BGEnd]**2))**0.5
-        RefRMSPulse = (np.mean(Data[Key[1]][PulseStart:PulseEnd]**2))**0.5
-#            RefRMS = RefRMSPulse
-        if RefRMSPulse < RefRMSBG: RefRMS = RefRMSPulse
-        else: RefRMS = RefRMSPulse - RefRMSBG
-
-        # GPIAS index (How much Res is different from Ref)
-        Index[Key[2]] = (RefRMS-ResRMS)/RefRMS
-
-    return(Index)
-
-
 def IndexCalc(Data, Keys, PulseSampleStart, SliceSize, BGNormalize=True):
     Index = {}
     for Key in Keys:
@@ -300,17 +234,12 @@ def IndexCalc(Data, Keys, PulseSampleStart, SliceSize, BGNormalize=True):
     return(Index)
 
 
-def PreallocateDict(Freqs):#, PrePostFreq=None):
+def PreallocateDict(Freqs):
     Dict = {
         Key: {'-'.join([str(Freq[0]), str(Freq[1])]): {} for Freq in Freqs}
         for Key in ['Trace', 'Index', 'IndexTrace']
     }
 
-    # if PrePostFreq:
-    #     for Key in ['Trace', 'Index', 'IndexTrace']:
-    #         Dict[Key][PrePostFreq]['Pre'] = []
-    #         Dict[Key][PrePostFreq]['Post'] = []
-
     for Freq in Dict['Trace'].keys():
         Dict['Trace'][Freq]['NoGap'] = []; Dict['Trace'][Freq]['Gap'] = []
         Dict['IndexTrace'][Freq]['NoGap'] = []; Dict['IndexTrace'][Freq]['Gap'] = []
@@ -340,9 +269,9 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
             TTLs = sAnalysis.QuantifyTTLsPerRec(AnalogTTLs, Rec[:,DataInfo['DAqs']['TTLCh']-1])
             if len(TTLs) > 1:
                 print('More than one TTL detected!!')
-                # TTLs = [Rec[:,DataInfo['DAqs']['TTLCh']-1].argmax()]
-                TTLs = [TTLs[0]]
-            print(TTLs)
+                # TTLs = [Rec[:,DataInfo['DAqs']['TTLCh']-1].argmax()]    # Get larger TTL
+                TTLs = [TTLs[0]]                                          # Get first TTL
+            # print(TTLs)
 
             if not TTLs: print('No TTL detected. Skipping trial...'); continue
 
@@ -364,19 +293,6 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
                                      int(TimeWindow[1]*Rate), AnalogTTLs)
 
         elif len(DataInfo['DAqs']['RecCh']) == 3:
-            ## Testing
-            # X = Rec[:,DataInfo['DAqs']['RecCh'][0]-1]
-            # Y = Rec[:,DataInfo['DAqs']['RecCh'][1]-1]
-            # Z = Rec[:,DataInfo['DAqs']['RecCh'][2]-1]
-
-            # GD = [
-            #     np.abs(X-X.mean()),
-            #     np.abs(Y-Y.mean()),
-            #     np.abs(Z-Z.mean())]
-            # GD = [sAnalysis.SliceData(
-            #     _, TTLs, -int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate),
-            #     AnalogTTLs) for _ in GD]
-
             X = sAnalysis.FilterSignal(Rec[:,DataInfo['DAqs']['RecCh'][0]-1],
                                           Rate, FilterFreq, FilterOrder, Filter, FilterType)
             Y = sAnalysis.FilterSignal(Rec[:,DataInfo['DAqs']['RecCh'][1]-1],
@@ -389,18 +305,12 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
                 np.abs(Y-Y.mean()),
                 np.abs(Z-Z.mean())], axis=0)
 
-            # GD = np.mean([
-            #     -(X-X.mean()),
-            #     Y-Y.mean(),
-            #     Z-Z.mean()], axis=0)
-
             GD -= GD.mean()
 
             GD = sAnalysis.SliceData(
                 GD, TTLs, -int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate),
             )
 
-
         Dict['IndexTrace'][SFreq][STrial].append(GD)
         Dict['Trace'][SFreq][STrial].append(GD)
 
@@ -419,8 +329,6 @@ def GetAllTrials(
             if len(FilterFreq) == 1: FilterType = 'lowpass'
             else: FilterType = 'bandpass'
 
-        # PrePostFreq = None
-
         GPIASData = Data.copy()
         for Key in ['IndexTrace', 'Trace']:
             for F,Freq in GPIASData[Key].items():
@@ -441,19 +349,12 @@ def GetAllTrials(
         del(GD)
 
     else:
-        # PrePostFreq = DataInfo['ExpInfo']['FreqOrder'][0][0]
-        # PrePostFreq = '-'.join([str(DataInfo['Audio']['NoiseFrequency'][PrePostFreq][0]),
-        #                         str(DataInfo['Audio']['NoiseFrequency'][PrePostFreq][1])])
-
-        # if '0' not in Data:
-        #     Data = {str(int(K)-1): V for K,V in Data.items()}
-
-        GPIASData = PreallocateDict(DataInfo['Audio']['NoiseFrequency'])#, PrePostFreq)
+        GPIASData = PreallocateDict(DataInfo['Audio']['NoiseFrequency'])
         GPIASData = OrganizeRecs(GPIASData, Data, Rate, DataInfo, AnalogTTLs,
                                        TimeWindow, None, None,
                                        FilterFreq, FilterOrder, FilterType, Filter)
 
-    return(GPIASData)#, PrePostFreq)
+    return(GPIASData)
 
 
 ## Level 2
@@ -494,7 +395,6 @@ def Analysis(Data, DataInfo, Rate, AnalysisFolder, AnalysisKey,
     X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
 
     if Save:
-        # Asdf.Write({'GPIAS': GPIASData, 'X': X}, AnalysisFolder+'/'+AnalysisKey+'.asdf')
         IO.Bin.Write({'GPIAS': GPIASData, 'X': X}, AnalysisFolder+'/'+AnalysisKey)
 
     if Return: return(GPIASData, X)
