@@ -112,8 +112,8 @@ def Multiple(ABRs, X, SpaceAmpF=1, StimDur=None, Peaks=[], PeaksColors=[], Color
     Y = Ax.get_ylim()
     if StimDur:
         Ax.plot([X[X>=0][0], X[X<=StimDur*1000][-1]], [max(Y)*1.2]*2, 'k', lw=3)
-#         FontDict = {'size':8, 'ha':'center', 'va':'bottom'}
-#         Ax.text(np.mean([X[X>=0][0], X[X<=StimDur*1000][-1]]), max(Y)*1.2, 'Sound pulse', fontdict=FontDict)
+        # FontDict = {'size':8, 'ha':'center', 'va':'bottom'}
+        # Ax.text(np.mean([X[X>=0][0], X[X<=StimDur*1000][-1]]), max(Y)*1.2, 'Sound pulse', fontdict=FontDict)
 
     Ax.tick_params(left=False)
     Ax.spines['left'].set_visible(False)
@@ -121,7 +121,7 @@ def Multiple(ABRs, X, SpaceAmpF=1, StimDur=None, Peaks=[], PeaksColors=[], Color
     YLabels = np.flipud([_[:-2] if _[:-2].lower() == 'db' else _ for _ in Recs])
     AxArgs['yticks'] = YTicks
     AxArgs['yticklabels'] = YLabels
-#     if 'ylim' not in AxArgs: AxArgs['ylim'] = Y
+    # if 'ylim' not in AxArgs: AxArgs['ylim'] = Y
     if 'xlim' not in AxArgs: AxArgs['xlim'] = [round(X[0],2), round(X[-1])]
     if 'xlabel' not in AxArgs: AxArgs['xlabel'] = 'Time [ms]'
     if 'ylabel' not in AxArgs: AxArgs['ylabel'] = 'Intensity [dB]'
@@ -141,11 +141,6 @@ def Multiple(ABRs, X, SpaceAmpF=1, StimDur=None, Peaks=[], PeaksColors=[], Color
         return(None)
 
 
-def Session(Folder):
-
-    return(None)
-
-
 def LatencyPerFreq(Latencies, Intensities,
                    Ax=None, AxArgs={}, File='ABRs-LatencyPerFreq', Ext=['svg'], Save=False, Show=True):
     ReturnAx = True
@@ -219,8 +214,6 @@ def ThresholdsPerFreq(Thresholds, Freqs,
         return(None)
 
 
-
-
 def Triang3D(ABRs, X, Azimuth=-110, Elevation=50, Step=1, Show=True):
     Plt = Plot.Return('Plt')
     Axes3D = Plot.Return('Axes3D')
@@ -265,14 +258,13 @@ def Triang3D(ABRs, X, Azimuth=-110, Elevation=50, Step=1, Show=True):
 
 
 ## Level 1
-def Traces_LatencyPerFreq_AllFreqs(ABRs, X, Latencies, Intensities, Thresholds, Freqs, SpaceAmpF=1.5, StimDur=None, Peaks=None,
-                                   File='ABRs-Traces_LatencyPerFreq_AllFreqs', Ext=['svg'], Save=False, Show=True):
+def Traces_LatencyPerFreq_AllFreqs(
+        ABRs, X, Latencies, Intensities, Thresholds, Freqs, SpaceAmpF=1.5, StimDur=None, Peaks=None,
+        File='ABRs-Traces_LatencyPerFreq_AllFreqs', Ext=['svg'], Save=False, Show=True
+    ):
     Plt = Plot.Return('Plt')
-    # GridSpec = Plot.Return('GridSpec')
 
     Fig = Plt.figure(figsize=(7.086614, 3.5), dpi=200)
-    # Grid = GridSpec(2, 2)
-    # Axes = [Fig.add_subplot(_) for _ in [Grid[:,0], Grid[0,1], Grid[1,1]]]
     Axes = [Plt.subplot2grid((2, 2), (0, 0), rowspan=2),
             Plt.subplot2grid((2, 2), (0, 1)),
             Plt.subplot2grid((2, 2), (1, 1))]
