@@ -72,7 +72,7 @@ def GetScreenInfo():
         Screen['DPI'] = [_.split('resolution')[1].split('\\n')[0].split('x')[0].split(' ')[-1] for _ in Screen['DPI']]
         Screen['DPI'] = [int(_) for _ in Screen['DPI']]
     except:
-        print('xdpyinfo not installed. Assuming a 96 dpi screen.')
+        print('xdpyinfo not available. Assuming a 96 dpi screen.')
         Screen['DPI'] = [96]
 
     try:
@@ -82,7 +82,7 @@ def GetScreenInfo():
         Screen['Size_px'] = [_.split('+')[0].split('x') for f in Size for _ in f.split(' ') if 'x' in _ and '+' in _]
         Screen['Size_px'] = [[int(_) for _ in s] for s in Screen['Size_px']]
     except:
-        print('xrandr not installed. Assuming a 15.6" full HD screen.')
+        print('xrandr not available. Assuming a 15.6" full HD screen.')
         Screen['Size_mm'] = [[344, 193]]
         Screen['Size_px'] = [[1920, 1080]]
 
@@ -409,15 +409,29 @@ def Return(Function):
 
 
 ## Level 2
-def ApplyColorMapToCycle(Ax, CMap=None, Interval=None, Reverse=False):
+def ApplyColorMapToCycle(Lines, CMap=None, Interval=[0,0.8]):
+    '''
+    Apply colormap colors as color cycle on a list of lines.
+
+    Parameters
+    ----------
+    Lines: list
+        List of `matplotlib.lines.Line2D` objects.
+
+    CMap: str or matplotlib.colors.ListedColormap
+        Colormap to be applied to color cycle.
+
+    Interval: list
+        List with start and end colormap values. Useful for when the extremes
+        of the colormap are the same as the figure background. Defaults to
+        `[0,0.8]`, since the colormap value of `1` gives white color for most
+        colormaps.
+    '''
+
     plt = Return('plt')
     if not CMap: CMap = plt.get_cmap()
     else: CMap = plt.get_cmap(CMap)
 
-    if not Interval: Interval = [0,0.8]
-
-    Lines = Ax.get_lines()
-    if Reverse: Lines.reverse()
     for L,Line in enumerate(Lines):
         Line.set_color(CMap(np.linspace(Interval[0],Interval[1],len(Lines)))[L])
 
@@ -729,29 +743,40 @@ def ScatterMean(Data, X=[], ColorsMarkers=[], ColorsLines=[], Alpha=0.4, XSpread
     XPoss = [np.random.uniform(Pos-XSpread, Pos+XSpread, len(Boxes[P])) for P,Pos in enumerate(X)]
     Errors = [[0, np.std(Box)/len(Box)**0.5, 0] for Box in Boxes]
     Colors = [ColorsMarkers, ColorsLines]
+    ErrorArgs = {**{'zorder': np.inf}, **ErrorArgs}
+
+    plt = Return('plt')
+    pCMap = plt.get_cmap(CMap)
 
     for C,ColorItem in enumerate(Colors):
         if not len(ColorItem):
-            if not CMap: Colors[C] = ['k']*max(len(Data), len(X))
-            else: Colors[C] = ['']*max(len(Data), len(X))
-        elif ColorItem == 'default':
-            Colors[C] = ['']*max(len(Data), len(X))
+            Colors[C] = ['k']*max(len(Data), len(X))
 
     Fig, Ax, ReturnAx = FigAx(Ax)
     for P,Pos in enumerate(X):
         Box, XPos, Error = Boxes[P], XPoss[P], Errors[P]
 
         if LogY:
-            Ax.semilogy(
+            pMarkers = Ax.semilogy(
                 XPos, Box, color=Colors[P], markeredgecolor=Colors[0][P],
                 markerfacecolor=Colors[0][P], marker=Marker, linestyle='', alpha=Alpha
             )
         else:
-            Ax.plot(
+            pMarkers = Ax.plot(
                 XPos, Box, color=Colors[1][P], markeredgecolor=Colors[0][P],
                 markerfacecolor=Colors[0][P], marker=Marker, linestyle='', alpha=Alpha, **PlotArgs
             )
-        Ax.errorbar([Pos-XSpread, Pos, Pos+XSpread], [np.mean(Box)]*3, Error, lw=3, elinewidth=1, capsize=5, color=Colors[1][P], **ErrorArgs)
+
+        if CMap:
+            pColors = pCMap(np.linspace(0,0.8,len(Box)))
+            for cl, CL in enumerate(pColors):
+                Ax.plot(
+                    pMarkers[0].get_xdata()[cl], pMarkers[0].get_ydata()[cl],
+                    color=CL, marker=pMarkers[0].get_marker(),
+                    linestyle=pMarkers[0].get_linestyle()
+                )
+
+        Ax.errorbar([Pos-XSpread, Pos, Pos+XSpread], [np.mean(Box)]*3, Error, lw=3, elinewidth=1, capsize=5, color=Colors[0][P], **ErrorArgs)
 
     if Paired:
         if len(np.unique([len(_) for _ in Data])) != 1:
@@ -770,7 +795,9 @@ def ScatterMean(Data, X=[], ColorsMarkers=[], ColorsLines=[], Alpha=0.4, XSpread
                 color=Colors[1][P], linestyle=Line, alpha=Alpha
             )
 
-        if CMap: ApplyColorMapToCycle(Ax, CMap=CMap)
+    # if CMap:
+        # CMapLines = [_ for _ in Ax.get_lines() if len(_.get_xdata()) == 2]
+        # ApplyColorMapToCycle(CMapLines, CMap=CMap)
 
     Ax.set_xlim([X[0]-(XSpread*2), X[-1]+(XSpread*2)])
     Ax.set_xticks(X)
