@@ -95,6 +95,9 @@ def CalibrateInput(Repetitions, TestAmp, SBOutAmpF, Freq, WaveDur, Rate, BlockSi
         SBInAmpF[aa] = (max(Rec[2000:])-(min(Rec[2000:])))/2
         print(SBInAmpF[aa])
 
+    if SBInAmpF.mean() == 0:
+        raise ValueError('The measured signal is 0V. Is the mic on?')
+
     # SBInAmpF is the real amplitude divided by the measured amplitude
     SBInAmpF = TestAmp/SBInAmpF.mean()
     print('SBInAmpF = ', str(SBInAmpF))
