@@ -14,19 +14,61 @@ CalibrationPath = os.environ['DATAPATH']+'/Tests/SoundMeasurements'
 
 
 ## Level 0
+def NoCalibrationMsg(System, Setup):
+    FullPath = f'{CalibrationPath}/{System}/{Setup}'
+    Msg = f'No such file or directory: {FullPath}'+r'''
+Calibration files for
+    System ''' + System + r'''
+    Setup  ''' + Setup + r'''
+were not found. You have to calibrate your setup before using it, or manually
+provide the voltage amplification factor that will be applied to the speaker
+using the SoundAmpF variable.
+
+For more details, read the sciscripts.Exps.SoundMeasurements documentation:
+    sciscripts.Exps import SoundMeasurements
+    print(SoundMeasurements.__doc__)
+'''
+    return(Msg)
+
+
+# Level 1
+def CalibrationLoad(Dataset, System, Setup):
+    FullPath = f'{CalibrationPath}/{System}/{Setup}/{Dataset}'
+    try:
+        Data = IO.Bin.Read(FullPath)[0]
+    except FileNotFoundError as e:
+        raise Exception(NoCalibrationMsg(System,Setup)) from e
+
+    return(Data)
+
+
+def Normalize(Data, System, Mode=''):
+    try:
+        AmpF = IO.Txt.Read(CalibrationPath+'/'+System+'/AmpF.txt')
+    except FileNotFoundError as e:
+        raise Exception(NoCalibrationMsg(System,'')) from e
+
+    if Mode.lower() == 'in': Data *= AmpF['InAmpF']
+    elif Mode.lower() == 'out': Data *= AmpF['OutAmpF']
+    else: print('"Mode" should be "in" or "out"'); return(None)
+
+    return(Data)
+
+
+# Level 2
 def GetPSD(System, Setup):
-    PSD = IO.Bin.Read(CalibrationPath+'/'+System+'/'+Setup+'/PSD')[0]
+    PSD = CalibrationLoad('PSD', System, Setup)
     return(PSD)
 
 
 def GetSoundIntensity(System, Setup):
-    SoundIntensity = IO.Bin.Read(CalibrationPath+'/'+System+'/'+Setup+'/SoundIntensity')[0]
+    SoundIntensity = CalibrationLoad('SoundIntensity', System, Setup)
     return(SoundIntensity)
 
 
 def GetSoundRec(System, Setup, Freq=''):
     if Freq: Freq = '/'+Freq
-    SoundRec = IO.Bin.Read(CalibrationPath+'/'+System+'/'+Setup+'/SoundRec'+Freq)[0]
+    SoundRec = CalibrationLoad('SoundRec'+Freq, System, Setup)
 
     if Freq:
         SoundRec = {A.replace('_', '.'): AmpF for A, AmpF in SoundRec.items()}
@@ -37,16 +79,7 @@ def GetSoundRec(System, Setup, Freq=''):
     return(SoundRec)
 
 
-def Normalize(Data, System, Mode=''):
-    AmpF = IO.Txt.Read(CalibrationPath+'/'+System+'/AmpF.txt')
-    if Mode.lower() == 'in': Data *= AmpF['InAmpF']
-    elif Mode.lower() == 'out': Data *= AmpF['OutAmpF']
-    else: print('"Mode" should be "in" or "out"'); return(None)
-
-    return(Data)
-
-
-## Level 1
+# Level 3
 def dBToAmpF(Intensities, System, Setup):
     print('Converting dB to AmpF...')
     SoundIntensity = GetSoundIntensity(System, Setup)
@@ -65,24 +98,5 @@ def dBToAmpF(Intensities, System, Setup):
         for F,Freq in enumerate(SoundIntensity['Freqs'])
     }
 
-    # Tmp override
-    SoundAmpF50_45 = {
-        '8000-10000': [0.0017635, 0.00088175],
-        '8000-18000': [0.0002105, 0.00010525],
-        '9000-11000': [0.0014025, 0.00070125],
-        '10000-12000': [0.000979, 0.0004895],
-        '12000-14000': [0.001045, 0.0005225],
-        '14000-16000': [0.0014025, 0.00070125],
-        '16000-18000': [0.0021455, 0.00107275]
-    }
-
-    for db,dB in enumerate([50, 45]):
-        if dB in Intensities:
-            Ind = Intensities.index(dB)
-
-            for F,Freq in SoundAmpF.items():
-                Freq[Ind] = SoundAmpF50_45[F][db]
-                SoundAmpF[F] = Freq
-
     return(SoundAmpF)
 
